Set the background on the vbox, not the main_window.
authorTom Adams <tom@holizz.com>
Mon, 29 Jun 2009 09:48:56 +0000 (10:48 +0100)
committerMason Larobina <mason.larobina@gmail.com>
Mon, 29 Jun 2009 09:57:30 +0000 (17:57 +0800)
uzbl.c

diff --git a/uzbl.c b/uzbl.c
index c0cd77f..e5db9e7 100644 (file)
--- a/uzbl.c
+++ b/uzbl.c
@@ -2118,9 +2118,8 @@ update_title (void) {
         if (b->status_background) {
             GdkColor color;
             gdk_color_parse (b->status_background, &color);
-            //labels and hboxes do not draw their own background.  applying this on the window is ok as we the statusbar is the only affected widget.  (if not, we could also use GtkEventBox)
-            if (uzbl.gui.main_window)
-                gtk_widget_modify_bg (uzbl.gui.main_window, GTK_STATE_NORMAL, &color);
+            //labels and hboxes do not draw their own background. applying this on the vbox is ok as the statusbar is the only affected widget. (if not, we could also use GtkEventBox)
+            gtk_widget_modify_bg (uzbl.gui.vbox, GTK_STATE_NORMAL, &color);
         }
     } else {
         if (b->title_format_long) {